@@ -16,14 +16,14 @@
 #ifndef LIBRADIUS_H
 #define LIBRADIUS_H
 /*
- * $Id: 545be09dfca447007423245068397e1aca51a6f9 $
+ * $Id: 4a798572b44bf2ea16ff8b87463ff86f91b2d5bf $
  *
  * @file libradius.h
  * @brief Structures and prototypes for the radius library.
  *
  * @copyright 1999-2014 The FreeRADIUS server project
  */
-RCSIDH(libradius_h, "$Id: 545be09dfca447007423245068397e1aca51a6f9 $")
+RCSIDH(libradius_h, "$Id: 4a798572b44bf2ea16ff8b87463ff86f91b2d5bf $")
 
 /*
  *  Compiler hinting macros.  Included here for 3rd party consumers
@@ -205,7 +205,7 @@ extern const FR_NAME_NUMBER dict_attr_types[];
 extern const size_t dict_attr_sizes[PW_TYPE_MAX][2];
 extern const int fr_attr_max_tlv;
 extern const int fr_attr_shift[];
-extern const int fr_attr_mask[];
+extern const unsigned int fr_attr_mask[];
 
 /** dictionary attribute
  *
@@ -418,6 +418,7 @@ typedef enum {
 	DECODE_FAIL_ATTRIBUTE_UNDERFLOW,
 	DECODE_FAIL_TOO_MANY_ATTRIBUTES,
 	DECODE_FAIL_MA_MISSING,
+	DECODE_FAIL_TOO_MANY_AUTH,
 	DECODE_FAIL_MAX
 } decode_fail_t;
 
@@ -487,6 +488,7 @@ DICT_ATTR const	*dict_attrbytype(unsigned int attr, unsigned int vendor,
 				 PW_TYPE type);
 DICT_ATTR const	*dict_attrbyparent(DICT_ATTR const *parent, unsigned int attr,
 					   unsigned int vendor);
+DICT_ATTR const *dict_parent(unsigned int attr, unsigned int vendor);
 int		dict_attr_child(DICT_ATTR const *parent,
 				unsigned int *pattr, unsigned int *pvendor);
 DICT_VALUE	*dict_valbyattr(unsigned int attr, unsigned int vendor, int val);
@@ -703,6 +705,7 @@ void		fr_printf_log(char const *, ...) CC_HINT(format (printf, 1, 2));
  *	Several handy miscellaneous functions.
  */
 int		fr_set_signal(int sig, sig_t func);
+int		fr_unset_signal(int sig);
 int		fr_link_talloc_ctx_free(TALLOC_CTX *parent, TALLOC_CTX *child);
 char const	*fr_inet_ntop(int af, void const *src);
 char const 	*ip_ntoa(char *, uint32_t);
